#!/bin/sh

APP_NAME="Authentic8 client for Linux"
APP_VER="2.9.0"
INSTALL_PATH="$HOME/Authentic8"
INSTALL_INFO_FILENAME=$HOME/.Authentic8.install.log
LASTINSTALLPATH=""

if [ -e $HOME/.Authentic8.install.log ]; then
    . $HOME/.Authentic8.install.log
fi

is_number()
{
    case $1 in
        ''|*[!0-9]*) return 0 ;;
        *) return 1 ;;
    esac
    return 0
}

install_client()
{
    echo "installing to $INSTALL_PATH"

    if [ -d $INSTALL_PATH ]; then
        echo "directory exist, not creating"
    else
        echo "directory does not exist, creating"
        mkdir $INSTALL_PATH
        if [ ! -d $INSTALL_PATH ]; then
            echo "failed to create directory"
            return 1
        fi
    fi

    echo "copying files"
    cp -a client/* $INSTALL_PATH
    cp icon_32x32.png $INSTALL_PATH
    if [ $? -eq 0 ]; then
        if [ -e $INSTALL_PATH/a8cli ]; then
            echo "install successed"
        else
            echo "install failed"
            return 1
        fi
    else
        echo "install failed"
    fi
    
    echo "setting permissions"
    chmod +x "$INSTALL_PATH/a8cli"
    if [ $? -ne 0 ]; then
        echo "setting $INSTALL_PATH/a8cli permissions failed"
    fi
    ldd $INSTALL_PATH/a8cli > /dev/null 2>&1
    if [ $? -ne 0 ]; then
        echo "ldd $INSTALL_PATH/a8cli failed"
    fi
    # save the install path so we can uninstall it
    echo "LASTINSTALLPATH=$INSTALL_PATH" > $INSTALL_INFO_FILENAME
    return 0
}

remove_client()
{
    if [ "$LASTINSTALLPATH" != "" ]; then
        echo "removing $LASTINSTALLPATH"
        echo "Are you sure?  Enter to proceed control c to quit"
        read dummy
        rm -rf $LASTINSTALLPATH
        rm -f $INSTALL_INFO_FILENAME
        rm -f $HOME/Desktop/Authentic8.desktop
    else
        echo "It does not appear that the Authentic8 client is installed, nothing to remove"
    fi
    return 0
}

ask_path()
{
    in_ask_path=""
    echo "Please enter the directory in which $APP_NAME is to be installed."
    echo -n "default: [$INSTALL_PATH]:"
    read in_ask_path
    echo ""
    if [ "$in_ask_path" != "" ]; then
        INSTALL_PATH=$in_ask_path
    fi
    return 0
}

desktop_icon()
{
    echo "Creating desktop icon"
    echo "#!/usr/bin/env xdg-open"            > $HOME/Desktop/Authentic8.desktop
    echo "[Desktop Entry]"                   >> $HOME/Desktop/Authentic8.desktop
    echo "Comment[en_US]="                   >> $HOME/Desktop/Authentic8.desktop
    echo "Comment="                          >> $HOME/Desktop/Authentic8.desktop
    echo "Exec=$INSTALL_PATH/a8cli.sh"       >> $HOME/Desktop/Authentic8.desktop
    echo "GenericName[en_US]="               >> $HOME/Desktop/Authentic8.desktop
    echo "GenericName="                      >> $HOME/Desktop/Authentic8.desktop
    echo "Icon=$INSTALL_PATH/icon_32x32.png" >> $HOME/Desktop/Authentic8.desktop
    echo "MimeType="                         >> $HOME/Desktop/Authentic8.desktop
    echo "Name[en_US]=Authentic8"            >> $HOME/Desktop/Authentic8.desktop
    echo "Name=Authentic8"                   >> $HOME/Desktop/Authentic8.desktop
    echo "Path="                             >> $HOME/Desktop/Authentic8.desktop
    echo "StartupNotify=true"                >> $HOME/Desktop/Authentic8.desktop
    echo "Terminal=false"                    >> $HOME/Desktop/Authentic8.desktop
    echo "TerminalOptions="                  >> $HOME/Desktop/Authentic8.desktop
    echo "Type=Application"                  >> $HOME/Desktop/Authentic8.desktop
    echo "X-DBUS-ServiceName="               >> $HOME/Desktop/Authentic8.desktop
    echo "X-DBUS-StartupType="               >> $HOME/Desktop/Authentic8.desktop
    echo "X-KDE-SubstituteUID=false"         >> $HOME/Desktop/Authentic8.desktop
    echo "X-KDE-Username="                   >> $HOME/Desktop/Authentic8.desktop
    chmod +x $HOME/Desktop/Authentic8.desktop

    echo "#!/bin/sh"                          > $INSTALL_PATH/a8cli.sh
    echo "cd $INSTALL_PATH"                  >> $INSTALL_PATH/a8cli.sh
    echo "exec $INSTALL_PATH/a8cli"          >> $INSTALL_PATH/a8cli.sh
    chmod +x $INSTALL_PATH/a8cli.sh

    return 0
}

echo "$APP_NAME $APP_VER setup."

echo "Copyright 2014 Authentic8, Inc. All rights reserved."
echo ""
echo "User install mode."
echo ""
echo "Select a setup option:"
echo ""
echo " 1. Install $APP_NAME $APP_VER"
echo " 2. Remove $APP_NAME $APP_VER"
echo " 3. Quit $APP_NAME $APP_VER setup"
echo ""
echo -n "Enter option number 1-3 [1]:"
read user_input
echo ""

if [ "$user_input" = "" ]; then
    user_input=1
fi

is_number $user_input
if [ $? -eq 0 ]; then
    echo "invalid input"
    exit 1
fi

if [ $user_input -eq 3 ]; then
    echo "Exiting"
    exit 0
fi

if [ $user_input -eq 2 ]; then
    echo "Removing..."
    remove_client
    exit 0
fi

if [ $user_input -eq 1 ]; then
    echo "Installing..."
    ask_path
    if [ $? -ne 0 ]; then
        echo "Error getting installation path"
        exit 1
    fi
    install_client
    if [ $? -ne 0 ]; then
        echo "Installation failed"
        exit 1
    fi
    desktop_icon
    exit 0
fi

echo "invalid input"
exit 1
